@@ -123,7 +123,7 @@ PlumeQuarto <- R6Class(
         email = private$get("email"),
         phone = private$get("phone"),
         fax = private$get("fax"),
-        orcid = private$get("orcid"),
+        orcid = private$author_orcid(),
         note = private$author_notes(),
         acknowledgements = private$get("acknowledgements"),
         attributes = private$author_attributes(),
@@ -133,6 +133,14 @@ PlumeQuarto <- R6Class(
       )
     },
 
+    author_orcid = function() {
+      out <- private$get("orcid")
+      if (!is.null(out)) {
+        check_orcid(out)
+      }
+      out
+    },
+
     author_roles = function() {
       col <- private$pick("role")
       if (!private$has_col(col)) {
