@@ -41,4 +41,9 @@ read_test_file <- function(file) {
 scrub_icon_path <- function(x) {
   path_regex <- "(?<=\\()(?:[A-Z]:)?\\/.+\\/(?=[\\w-]+\\.(?:pdf|svg)\\))"
   sub(path_regex, "", x, perl = TRUE)
-}
\ No newline at end of file
+}
+
+pull_nested_var <- function(cls, nested_var, pull) {
+  out <- unnest(cls$get_plume(), cols = all_of(nested_var))
+  out[[pull]]
+}
